@@ -1,11 +1,9 @@
 /*
-  $Id: MbtAPI.h 15567 2013-01-07 14:47:12Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/MbtAPI.h $
-
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbt
 
   mbt is free software; you can redistribute it and/or modify
@@ -22,25 +20,24 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #ifndef MBT_API_H
 #define MBT_API_H
 
 #include "timbl/TimblAPI.h"
-#include "ticcutils/LogStream.h"
 #include "mbt/Tagger.h"
 
-using namespace Timbl;
-using namespace TiCC;
-using namespace Tagger;
+namespace TiCC {
+  class LogStream;
+}
 
 class MbtAPI {
  public:
-  static bool GenerateTagger( TimblOpts& );
   static bool GenerateTagger( int, char** );
   static bool GenerateTagger( const std::string& );
   static bool RunTagger( int, char** );
@@ -49,10 +46,13 @@ class MbtAPI {
   ~MbtAPI();
   bool isInit() const;
   std::string Tag( const std::string& );
-  std::vector<TagResult> TagLine( const std::string& );
-  std::string getResult( const std::vector<TagResult>& ) const;
+  std::vector<Tagger::TagResult> TagLine( const std::string& );
+  std::string getResult( const std::vector<Tagger::TagResult>& ) const;
+  std::string set_eos_mark( const std::string& );
  private:
-  TaggerClass *tagger;
+  MbtAPI( const MbtAPI& ); // inhibit copies
+  MbtAPI& operator=( const MbtAPI& ); // inhibit copies
+  Tagger::TaggerClass *tagger;
 };
 
 #endif
