@@ -1,11 +1,9 @@
 /*
-  $Id: Pattern.h 15567 2013-01-07 14:47:12Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/Pattern.h $
-
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbt
 
   mbt is free software; you can redistribute it and/or modify
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 #ifndef MBT_PATTERN_H
 #define MBT_PATTERN_H
@@ -46,17 +44,17 @@ class PatTemplate {
   int numeric;
   int compensation;
   int wordfocus;
-  
+
   // todo:
   // int Cap1 : Cap1, CAPH, CAP1H
   // int non_alfanum
   // int num
 
   // int wordlength
-  // 
+  //
 
   PatTemplate();
-  ~PatTemplate(){;}
+  ~PatTemplate(){};
 
   int totalslots() const;
   int word_totalslots() const;
