@@ -1,11 +1,9 @@
 /*
-  $Id: Sentence.h 15567 2013-01-07 14:47:12Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/include/mbt/Sentence.h $
-
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbt
 
   mbt is free software; you can redistribute it and/or modify
@@ -22,9 +20,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 #ifndef MBT_SENTENCE_H
 #define MBT_SENTENCE_H
@@ -38,15 +36,15 @@ namespace Tagger {
   const std::string DOT = "==";
   const std::string UNKNOWN = "__";
   enum MatchAction { Unknown, Known, MakeKnown, MakeUnknown };
-  
+
   // A word in a sentence.
   //
   class word {
   public:
-    
+
     std::string the_word;
     int the_word_index;
-    
+
     std::string word_tag;
     int word_amb_tag;
     int word_ass_tag;
@@ -54,9 +52,9 @@ namespace Tagger {
     word( const std::string&, const std::string& );
     word( const std::string&, const std::vector<std::string>&, const std::string& );
     ~word();
-    
+
   };
-  
+
   enum word_stat { NO_MORE_WORDS, LAST_WORD, EOS_FOUND, READ_MORE };
   enum input_kind_type { UNTAGGED, TAGGED, ENRICHED };
 
@@ -65,38 +63,37 @@ namespace Tagger {
   class sentence {
     friend std::ostream& operator<< ( std::ostream& , const sentence& );
   public:
-    sentence();
+    sentence( const PatTemplate&, const PatTemplate& );
     ~sentence();
-
-    bool init_windowing( PatTemplate *, PatTemplate *, Lexicon&, StringHash& );
-    bool nextpat( MatchAction *, std::vector<int>&, StringHash& , StringHash&,
+    void clear();
+    bool init_windowing( Lexicon&, StringHash& );
+    bool nextpat( MatchAction&, std::vector<int>&, StringHash& , StringHash&,
 		  unsigned int, int * = 0 ) const;
     int classify_hapax( const std::string&, StringHash& ) const;
     void assign_tag( int, unsigned int );
     std::string getword( unsigned int i ) { return Words[i]->the_word; };
-    word *getWord( unsigned int i ) const { return Words[i]; };
     const std::string& gettag( int i ) const { return Words[i]->word_tag; };
+    const std::vector<std::string>& getEnrichments( unsigned int i )
+      const { return Words[i]->extraFeatures; };
     std::string getenr( unsigned int i );
     unsigned int size() const { return no_words; };
     bool known( unsigned int ) const;
-    std::string Eos() const;
-    bool read( std::istream &, input_kind_type, const std::string& );
-    bool fill( const std::string&, bool );
+    bool read( std::istream &, input_kind_type, const std::string&, size_t& );
   private:
     int UTAG;
     std::vector<word *> Words;
-    PatTemplate * Ktemplate;
-    PatTemplate * Utemplate;
+    std::string remainder;
+    const PatTemplate& Ktemplate;
+    const PatTemplate& Utemplate;
     unsigned int no_words;
     std::string InternalEosMark;
     bool Utt_Terminator( const std::string& );
-    word_stat get_word( std::istream& is, std::string& Word );
     void add( const std::string&, const std::vector<std::string>&,
 	      const std::string& );
     void add( const std::string&, const std::string& );
-    //    bool readLine( std::istream &, bool );
-    bool read( std::istream &, bool );
-    bool read_enriched( std::istream & );
+    bool read_tagged( std::istream&, size_t& );
+    bool read_untagged( std::istream&, size_t& );
+    bool read_enriched( std::istream&, size_t& );
     void print( std::ostream & ) const;
   };
 
