@@ -1,11 +1,9 @@
 /*
-  $Id: Mbt.cxx 15567 2013-01-07 14:47:12Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/src/Mbt.cxx $
-
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbt
 
   mbt is free software; you can redistribute it and/or modify
@@ -22,13 +20,14 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 //
-// Mbt tagger 
+// Mbt tagger
 //
 
 #include "mbt/MbtAPI.h"
@@ -38,4 +37,3 @@ using namespace std;
 int main(int argc, char *argv[]) {
   MbtAPI::RunTagger( argc, argv );
 }
-
