@@ -1,11 +1,9 @@
 /*
-  $Id: Mbtg.cxx 15567 2013-01-07 14:47:12Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/src/Mbtg.cxx $
-
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbt
 
   mbt is free software; you can redistribute it and/or modify
@@ -22,16 +20,16 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #include <cstdlib>
 #include "mbt/MbtAPI.h"
 
 int main(int argc, char *argv[]) {
-  MbtAPI::GenerateTagger( argc, argv );   
+  MbtAPI::GenerateTagger( argc, argv );
   exit(EXIT_SUCCESS);
 }
-
