@@ -1,11 +1,9 @@
 /*
-  $Id: TagLex.cxx 15830 2013-03-28 11:58:23Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/src/TagLex.cxx $
-
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbt
 
   mbt is free software; you can redistribute it and/or modify
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #include <algorithm>
@@ -40,29 +39,23 @@
 
 namespace Tagger {
   using namespace std;
-  
+
   TagInfo::TagInfo( const string& name, const string& tag ){
     Word = name;
     WordFreq = 0;
     Update( tag );
   }
-  
+
   TagInfo::~TagInfo(){
   }
-  
+
   void TagInfo::Update( const string& tag ){
     ++WordFreq;
-    map<string,int>::iterator it = TagFreqs.find( tag );
-    if ( it != TagFreqs.end() ){
-      ++it->second;
-    }
-    else {
-      TagFreqs[tag] = 1;
-    }
+    ++TagFreqs[tag];
   }
-  
+
   void TagInfo::Prune( int Threshold ){
-    map<string,int>::iterator it = TagFreqs.begin();
+    auto it = TagFreqs.begin();
     while ( it != TagFreqs.end() ){
       double perc = ( (double)it->second * 100 ) / ( double)WordFreq;
       if ( perc < Threshold )
@@ -71,13 +64,11 @@ namespace Tagger {
 	++it;
     }
   }
-  
+
   string TagInfo::DisplayTagFreqs( )const {
     string result;
-    map<string, int>::const_iterator it = TagFreqs.begin();
-    while ( it != TagFreqs.end() ){
-      result += it->first + ":" + TiCC::toString(it->second) + " ";
-      ++it;
+    for( const auto& it : TagFreqs ){
+      result += it.first + ":" + TiCC::toString(it.second) + " ";
     }
     return result;
   }
@@ -94,20 +85,15 @@ namespace Tagger {
 
   void TagInfo::CreateStringRepr(){
     vector<FS> FreqTags;
-    map<string,int>::const_iterator it = TagFreqs.begin();
-    while ( it != TagFreqs.end() ){
-      FreqTags.push_back( FS( it->second, it->first) );
-      ++it;
+    for ( const auto& it : TagFreqs ){
+      FreqTags.push_back( FS( it.second, it.first) );
     }
     sort( FreqTags.begin(), FreqTags.end(), cmpFreq );
     string tmpstr;
-    vector<FS>::const_iterator it2 = FreqTags.begin();
-    while ( it2 != FreqTags.end() ){
-      tmpstr += it2->str;
-      ++it2;
-      if ( it2 != FreqTags.end() )
-	tmpstr += ";";
+    for ( auto const& it2 : FreqTags ){
+      tmpstr += it2.str + ";";
     }
+    tmpstr.erase(tmpstr.length()-1); //remove last ';'
     StringRepr = tmpstr;
   }
 
@@ -118,20 +104,20 @@ namespace Tagger {
     }
     return os;
   }
-  
+
   TagLex::TagLex(){
     TagTree = new Trie<TagInfo>;
     NumOfEntries = 0;
   }
-  
+
   TagLex::~TagLex(){
     delete TagTree;
   }
-  
+
   TagInfo *TagLex::Lookup( const string& name ){
-    return (TagInfo *)TagTree->Retrieve( name ); 
+    return (TagInfo *)TagTree->Retrieve( name );
   }
-  
+
   TagInfo *TagLex::Store( const string& name, const string& tag ){
     TagInfo *info = TagTree->Retrieve( name );
     if ( !info ){
@@ -139,40 +125,42 @@ namespace Tagger {
       info = new TagInfo( name, tag );
       return TagTree->Store( name, info );
     }
-    else 
+    else
       info->Update( tag );
     return info;
   }
-  
+
   void StoreInVector( TagInfo *TI, void *arg ){
     vector<TagInfo*> *vec = (vector<TagInfo*> *)arg;
     vec->push_back( TI );
   }
-  
+
   bool ascendingInfo( const TagInfo* t1, const TagInfo* t2 ){
     //
     // sort on decending frequency
     // when same frequency, sort alphabetical
     // but: sort Uppercase words before lowercase when equal (e.g Land/land)
-    //     
+    //
     int diff = t2->Freq() - t1->Freq();
     if ( diff == 0 ){
-      if ( TiCC::lowercase(t2->Word) == TiCC::lowercase(t1->Word) )
-	return strcmp( t2->Word.c_str(), t1->Word.c_str() ) < 0;
-      else
-	return strcmp( t1->Word.c_str(), t2->Word.c_str() ) < 0;
+      if ( TiCC::lowercase(t2->Word) == TiCC::lowercase(t1->Word) ){
+	return t2->Word < t1->Word;
+      }
+      else {
+	return t1->Word < t2->Word;
+      }
     }
     return diff < 0;
   }
-  
+
   vector<TagInfo *> TagLex::CreateSortedVector(){
     vector<TagInfo*> TagVec;
     TagTree->ForEachDo( StoreInVector, (void *)&TagVec );
     sort( TagVec.begin(), TagVec.end() , ascendingInfo );
     return TagVec;
   }
-  
+
   ostream& operator<<( ostream& os, TagLex *L ){
     return os << L->TagTree; }
-  
+
 }
