@@ -1,11 +1,9 @@
 /*
-  $Id: convert.cxx 15567 2013-01-07 14:47:12Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/src/convert.cxx $
-
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbt
 
   mbt is free software; you can redistribute it and/or modify
@@ -22,9 +20,10 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #include <iostream>
@@ -64,12 +63,12 @@ void fill_map( istream& in, string_map& map ){
 }
 
 void backup( const string& in_name, const string& out_name ){
-  ifstream in( in_name.c_str() );
+  ifstream in( in_name );
   if ( !in ){
     cerr << "problems with inputfile: " << in_name << endl;
     exit(1);
   }
-  ofstream out( out_name.c_str() );
+  ofstream out( out_name );
   if ( !out ){
     cerr << "problems with opening backup file: " << out_name << endl;
     exit(1);
@@ -82,14 +81,14 @@ void backup( const string& in_name, const string& out_name ){
        << ")" << endl;
 }
 
-void convert( const string& in_name, const string& out_name, 
+void convert( const string& in_name, const string& out_name,
 	      string_map& tmap ){
-  ifstream in( in_name.c_str() );
+  ifstream in( in_name );
   if ( !in ){
     cerr << "problems with inputfile: " << in_name << endl;
     exit(1);
   }
-  ofstream out( out_name.c_str() );
+  ofstream out( out_name );
   if ( !out ){
     cerr << "problems with opening output file: " << out_name << endl;
     exit(1);
@@ -146,4 +145,3 @@ int main( int argc, char *argv[] ){
   backup( tree_file_name, back_name );
   convert( back_name, tree_file_name, tag_map );
 }
-
