@@ -1,11 +1,9 @@
 /*
-  $Id: simpletest.cxx 15567 2013-01-07 14:47:12Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/src/simpletest.cxx $
-
-  Copyright (c) 1998 - 2013
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbt
 
   mbt is free software; you can redistribute it and/or modify
@@ -22,14 +20,16 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #include <cstdlib>
 #include "mbt/MbtAPI.h"
 using namespace std;
+using namespace Tagger;
 
 int main(){
   string path = getenv( "topsrcdir" );
@@ -40,4 +40,3 @@ int main(){
   assert( v[0].assignedTag() == "N" );
   assert( v[2].confidence() == -1 );
 }
-
